summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--Lib/test/test_urllib2.py40
-rw-r--r--Lib/urllib/error.py4
-rw-r--r--Misc/NEWS2
3 files changed, 34 insertions, 12 deletions
diff --git a/Lib/urllib/error.py b/Lib/urllib/error.py
index c1dfc40..b712ebb 100644
--- a/Lib/urllib/error.py
+++ b/Lib/urllib/error.py
@@ -61,6 +61,10 @@ class HTTPError(URLError, urllib.response.addinfourl):
def reason(self):
return self.msg
+ def info(self):
+ return self.hdrs
+
+
# exception raised when downloaded size does not match content-length
class ContentTooShortError(URLError):
def __init__(self, message, content):
diff --git a/Misc/NEWS b/Misc/NEWS
index 97e24fa..31b3356 100644
--- a/Misc/NEWS
+++ b/Misc/NEWS
@@ -114,6 +114,8 @@ Core and Builtins
Library
-------
+- Issue #15701: Fix HTTPError info method call to return the headers information.
+
- Issue #16752: Add a missing import to modulefinder. Patch by Berker Peksag.
- Issue #16646: ftplib.FTP.makeport() might lose socket error details.
diff --git a/Lib/test/test_urllib2.py b/Lib/test/test_urllib2.py
index 2d94ba4..ccd5419 100644
--- a/Lib/test/test_urllib2.py
+++ b/Lib/test/test_urllib2.py
@@ -1495,18 +1495,34 @@ class RequestTests(unittest.TestCase):
req = Request(url)
self.assertEqual(req.get_full_url(), url)
-def test_HTTPError_interface():
- """
- Issue 13211 reveals that HTTPError didn't implement the URLError
- interface even though HTTPError is a subclass of URLError.
-
- >>> msg = 'something bad happened'
- >>> url = code = hdrs = fp = None
- >>> err = urllib.error.HTTPError(url, code, msg, hdrs, fp)
- >>> assert hasattr(err, 'reason')
- >>> err.reason
- 'something bad happened'
- """
+ def test_HTTPError_interface(self):
+ """
+ Issue 13211 reveals that HTTPError didn't implement the URLError
+ interface even though HTTPError is a subclass of URLError.
+
+ >>> msg = 'something bad happened'
+ >>> url = code = hdrs = fp = None
+ >>> err = urllib.error.HTTPError(url, code, msg, hdrs, fp)
+ >>> assert hasattr(err, 'reason')
+ >>> err.reason
+ 'something bad happened'
+ """
+
+ def test_HTTPError_interface_call(self):
+ """
+ Issue 15701 - HTTPError interface has info method available from URLError
+ """
+ err = urllib.request.HTTPError(msg="something bad happened", url=None,
+ code=None, hdrs='Content-Length:42', fp=None)
+ self.assertTrue(hasattr(err, 'reason'))
+ assert hasattr(err, 'reason')
+ assert hasattr(err, 'info')
+ assert callable(err.info)
+ try:
+ err.info()
+ except AttributeError:
+ self.fail('err.info call failed.')
+ self.assertEqual(err.info(), "Content-Length:42")
def test_main(verbose=None):
from test import test_urllib2